# mypy-boto3-elbv2

[![PyPI - mypy-boto3-elbv2](https://img.shields.io/pypi/v/mypy-boto3-elbv2.svg?color=blue)](https://pypi.org/project/mypy-boto3-elbv2)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-elbv2.svg?color=blue)](https://pypi.org/project/mypy-boto3-elbv2)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.ElasticLoadBalancingv2 1.17.49](https://boto3.amazonaws.com/v1/documentation/api/1.17.49/reference/services/elbv2.html#ElasticLoadBalancingv2) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.4.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-elbv2](#mypy-boto3-elbv2)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `ElasticLoadBalancingv2` service.

```bash
python -m pip install boto3-stubs[elbv2]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[elbv2]` in your environment: `python -m pip install 'boto3-stubs[elbv2]'`

Both type checking and auto-complete should work for `ElasticLoadBalancingv2` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[elbv2]` in your environment: `python -m pip install 'boto3-stubs[elbv2]'`

Both type checking and auto-complete should work for `ElasticLoadBalancingv2` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[elbv2]` in your environment: `python -m pip install 'boto3-stubs[elbv2]'`
- Run `mypy` as usual

Type checking should work for `ElasticLoadBalancingv2` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[elbv2]` in your environment: `python -m pip install 'boto3-stubs[elbv2]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `ElasticLoadBalancingv2` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`ElasticLoadBalancingv2Client` provides annotations for `boto3.client("elbv2")`.

```python
import boto3

from mypy_boto3_elbv2 import ElasticLoadBalancingv2Client

client: ElasticLoadBalancingv2Client = boto3.client("elbv2")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: ElasticLoadBalancingv2Client = session.client("elbv2")
```

### Paginators annotations

`mypy_boto3_elbv2.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_elbv2 import ElasticLoadBalancingv2Client
from mypy_boto3_elbv2.paginator import (
    DescribeAccountLimitsPaginator,
    DescribeListenerCertificatesPaginator,
    DescribeListenersPaginator,
    DescribeLoadBalancersPaginator,
    DescribeRulesPaginator,
    DescribeSSLPoliciesPaginator,
    DescribeTargetGroupsPaginator,
)

client: ElasticLoadBalancingv2Client = boto3.client("elbv2")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_account_limits_paginator: DescribeAccountLimitsPaginator = client.get_paginator("describe_account_limits")
describe_listener_certificates_paginator: DescribeListenerCertificatesPaginator = client.get_paginator("describe_listener_certificates")
describe_listeners_paginator: DescribeListenersPaginator = client.get_paginator("describe_listeners")
describe_load_balancers_paginator: DescribeLoadBalancersPaginator = client.get_paginator("describe_load_balancers")
describe_rules_paginator: DescribeRulesPaginator = client.get_paginator("describe_rules")
describe_ssl_policies_paginator: DescribeSSLPoliciesPaginator = client.get_paginator("describe_ssl_policies")
describe_target_groups_paginator: DescribeTargetGroupsPaginator = client.get_paginator("describe_target_groups")
```


### Waiters annotations

`mypy_boto3_elbv2.waiter` module contains type annotations for all waiters.

```python
from mypy_boto3_elbv2 import ElasticLoadBalancingv2Client
from mypy_boto3_elbv2.waiter import (
    LoadBalancerAvailableWaiter,
    LoadBalancerExistsWaiter,
    LoadBalancersDeletedWaiter,
    TargetDeregisteredWaiter,
    TargetInServiceWaiter,
)

client: ElasticLoadBalancingv2Client = boto3.client("elbv2")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
load_balancer_available_waiter: LoadBalancerAvailableWaiter = client.get_waiter("load_balancer_available")
load_balancer_exists_waiter: LoadBalancerExistsWaiter = client.get_waiter("load_balancer_exists")
load_balancers_deleted_waiter: LoadBalancersDeletedWaiter = client.get_waiter("load_balancers_deleted")
target_deregistered_waiter: TargetDeregisteredWaiter = client.get_waiter("target_deregistered")
target_in_service_waiter: TargetInServiceWaiter = client.get_waiter("target_in_service")
```





### Typed dictionations

`mypy_boto3_elbv2.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_elbv2.type_defs import (
    ActionTypeDef,
    AuthenticateCognitoActionConfigTypeDef,
    AuthenticateOidcActionConfigTypeDef,
    AvailabilityZoneTypeDef,
    CertificateTypeDef,
    CipherTypeDef,
    FixedResponseActionConfigTypeDef,
    ForwardActionConfigTypeDef,
    HostHeaderConditionConfigTypeDef,
    HttpHeaderConditionConfigTypeDef,
    HttpRequestMethodConditionConfigTypeDef,
    LimitTypeDef,
    ListenerTypeDef,
    LoadBalancerAddressTypeDef,
    LoadBalancerAttributeTypeDef,
    LoadBalancerStateTypeDef,
    LoadBalancerTypeDef,
    MatcherTypeDef,
    PathPatternConditionConfigTypeDef,
    QueryStringConditionConfigTypeDef,
    QueryStringKeyValuePairTypeDef,
    RedirectActionConfigTypeDef,
    ResponseMetadata,
    RuleConditionTypeDef,
    RuleTypeDef,
    SourceIpConditionConfigTypeDef,
    SslPolicyTypeDef,
    TagDescriptionTypeDef,
    TagTypeDef,
    TargetDescriptionTypeDef,
    TargetGroupAttributeTypeDef,
    TargetGroupStickinessConfigTypeDef,
    TargetGroupTupleTypeDef,
    TargetGroupTypeDef,
    TargetHealthDescriptionTypeDef,
    TargetHealthTypeDef,
    AddListenerCertificatesOutputTypeDef,
    CreateListenerOutputTypeDef,
    CreateLoadBalancerOutputTypeDef,
    CreateRuleOutputTypeDef,
    CreateTargetGroupOutputTypeDef,
    DescribeAccountLimitsOutputTypeDef,
    DescribeListenerCertificatesOutputTypeDef,
    DescribeListenersOutputTypeDef,
    DescribeLoadBalancerAttributesOutputTypeDef,
    DescribeLoadBalancersOutputTypeDef,
    DescribeRulesOutputTypeDef,
    DescribeSSLPoliciesOutputTypeDef,
    DescribeTagsOutputTypeDef,
    DescribeTargetGroupAttributesOutputTypeDef,
    DescribeTargetGroupsOutputTypeDef,
    DescribeTargetHealthOutputTypeDef,
    ModifyListenerOutputTypeDef,
    ModifyLoadBalancerAttributesOutputTypeDef,
    ModifyRuleOutputTypeDef,
    ModifyTargetGroupAttributesOutputTypeDef,
    ModifyTargetGroupOutputTypeDef,
    PaginatorConfigTypeDef,
    RulePriorityPairTypeDef,
    SetIpAddressTypeOutputTypeDef,
    SetRulePrioritiesOutputTypeDef,
    SetSecurityGroupsOutputTypeDef,
    SetSubnetsOutputTypeDef,
    SubnetMappingTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> ActionTypeDef:
    return {
      ...
    }
```
